@@ -155,7 +155,7 @@ class APIConnection:
         #
         # https://retdec.com/api/docs/essential_information.html#id3
         _, params = cgi.parse_header(headers.get('Content-Disposition', ''))
-        return params.get('filename', None)
+        return params.get('filename')
 
     def __repr__(self):
         return '<{} base_url={!r}>'.format(
