@@ -22,7 +22,10 @@ class MissingAPIKeyError(RetdecError):
 
 
 class MissingParameterError(RetdecError):
-    """Exception raised when a required parameter is not set."""
+    """Exception raised when a required parameter is not set.
+
+    :param str name: Name of the missing parameter.
+    """
 
     def __init__(self, name):
         super().__init__(
@@ -31,7 +34,11 @@ class MissingParameterError(RetdecError):
 
 
 class InvalidValueError(RetdecError):
-    """Exception raised when a parameter has an invalid value."""
+    """Exception raised when a parameter has an invalid value.
+
+    :param str name: Name of the parameter whose value is invalid.
+    :param value: The invalid value.
+    """
 
     def __init__(self, name, value):
         super().__init__(
@@ -51,35 +58,14 @@ class AuthenticationError(RetdecError):
 class ConnectionError(RetdecError):
     """Exception raised when there is a connection error."""
 
-    def __init__(self, reason=None):
-        message = _message_with_reason(
-            'Connection to the API failed.',
-            reason
-        )
-        super().__init__(message)
-
 
 class AnalysisFailedError(RetdecError):
     """Exception raised when a fileinfo analysis has failed."""
 
-    def __init__(self, reason=None):
-        message = _message_with_reason(
-            'The analysis has failed.',
-            reason
-        )
-        super().__init__(message)
-
 
 class DecompilationFailedError(RetdecError):
     """Exception raised when a decompilation has failed."""
 
-    def __init__(self, reason=None):
-        message = _message_with_reason(
-            'The decompilation has failed.',
-            reason
-        )
-        super().__init__(message)
-
 
 class OutputNotRequestedError(RetdecError):
     """Exception raised when an output is queried which was not requested to be
@@ -92,16 +78,32 @@ class OutputNotRequestedError(RetdecError):
         )
 
 
+class CGGenerationFailedError(RetdecError):
+    """Exception raised when the generation of a call graph fails.
+    """
+
+
+class CFGGenerationFailedError(RetdecError):
+    """Exception raised when the generation of a control-flow graph fails."""
+
+
+class NoSuchCFGError(RetdecError):
+    """Exception raised when a control-flow graph for a non-existing function
+    is requested.
+
+    :param str func: Name of the function whose control-flow graph was
+        requested.
+    """
+
+    def __init__(self, func):
+        super().__init__(
+            "There is no control-flow graph for '{}'.".format(func)
+        )
+
+
 class ArchiveGenerationFailedError(RetdecError):
     """Exception raised when the generation of an archive fails."""
 
-    def __init__(self, reason=None):
-        message = _message_with_reason(
-            'The archive generation has failed.',
-            reason
-        )
-        super().__init__(message)
-
 
 class UnknownAPIError(RetdecError):
     """Exception raised when there is an unknown API error.
@@ -132,13 +134,3 @@ class UnknownAPIError(RetdecError):
     def description(self):
         """Longer description of what went wrong (`str`)."""
         return self._description
-
-
-def _message_with_reason(message, reason):
-    """Returns `message` with `reason`.
-
-    If `reason` is ``None``, it returns just `message`.
-    """
-    if reason is not None:
-        message += ' Reason: {}'.format(reason)
-    return message
